@@ -6,24 +6,26 @@ from typing import Union
 from bs4 import BeautifulSoup
 from bs4.element import Tag
 
+from .connection import join_url
+from .connection import root
 from .parse import check_page_raise
 from .parse import parse_journal_page
 from .parse import parse_journal_section
+from .user import User
 
 
 class Journal:
     def __init__(self, journal_item: Union[Tag, BeautifulSoup] = None):
-        assert journal_item is None or isinstance(journal_item, BeautifulSoup) or isinstance(journal_item, Tag)
+        assert journal_item is None or isinstance(journal_item, (BeautifulSoup, Tag))
 
         self.journal_item: Optional[Union[Tag, BeautifulSoup]] = journal_item
 
         self.id: int = 0
         self.title: str = ""
         self.date: str = ""
-        self.author: str = ""
+        self.author: User = User()
         self.content: str = ""
         self.mentions: List[str] = []
-        self.user_icon_url: str = ""
 
         self.parse()
 
@@ -31,10 +33,9 @@ class Journal:
         yield "id", self.id
         yield "title", self.title
         yield "date", self.date
-        yield "author", self.author
+        yield "author", dict(self.author)
         yield "content", self.content
         yield "mentions", self.mentions
-        yield "user_icon_url", self.user_icon_url
 
     def __repr__(self):
         return repr(dict(self))
@@ -42,9 +43,13 @@ class Journal:
     def __str__(self):
         return f"{self.id} {self.author} {self.title}"
 
+    @property
+    def url(self):
+        return join_url(root, "journal", self.id)
+
     def parse(self, journal_item: Union[Tag, BeautifulSoup] = None):
-        assert journal_item is None or isinstance(journal_item, BeautifulSoup) or isinstance(journal_item, Tag)
-        self.journal_item = journal_item if journal_item is not None else self.journal_item
+        assert journal_item is None or isinstance(journal_item, (BeautifulSoup, Tag))
+        self.journal_item = journal_item or self.journal_item
         if self.journal_item is None:
             return
 
@@ -57,8 +62,9 @@ class Journal:
 
         self.id = parsed["id"]
         self.title = parsed["title"]
-        self.author = parsed.get("author", "")
+        self.author.name = parsed.get("user_name", "")
+        self.author.status = parsed.get("user_status", "")
+        self.author.user_icon_url = parsed.get("user_icon_url", "")
         self.date = parsed["date"]
         self.content = parsed["content"]
         self.mentions = parsed["mentions"]
-        self.user_icon_url: str = parsed.get("user_icon_url", "")
