@@ -1,9 +1,11 @@
 from re import Pattern
 from re import compile as re_compile
 from re import match
+from re import search
 from re import sub
 from typing import Dict
 from typing import List
+from typing import Optional
 from typing import Tuple
 from typing import Union
 
@@ -61,9 +63,13 @@ def check_page_raise(page: BeautifulSoup):
         raise NoticeMessage
 
 
+def username_url(username: str) -> str:
+    return sub(r"[^a-z0-9.~-]", "", username.lower())
+
+
 def parse_mentions(tag: Tag) -> List[str]:
     return sorted(set(ms := list(filter(bool, (
-        sub(r"[^a-z0-9.~-]", "", m.group(1).lower())
+        username_url(m.group(1).lower())
         for a in tag.select("a")
         if (m := match(mentions_regexp, a.attrs.get("href"))) is not None
     )))), key=ms.index)
@@ -86,29 +92,25 @@ def parse_journal_section(section_tag: Tag) -> Dict[str, Union[int, str]]:
 
 
 def parse_journal_page(journal_page: BeautifulSoup) -> Dict[str, Union[int, str]]:
+    user_info: Dict[str, str] = parse_user_folder(journal_page)
     tag_id: Tag = journal_page.select_one("meta[property='og:url']")
     tag_title: Tag = journal_page.select_one("h2.journal-title")
-    tag_author: Tag = journal_page.select_one("a.current")
     tag_date: Tag = journal_page.select_one("span.popup_date")
     tag_content: Tag = journal_page.select_one("div.journal-content")
-    tag_user_icon_url: Tag = journal_page.select_one("img.user-nav-avatar")
 
     id_: int = int(tag_id["content"].strip("/").split("/")[-1])
     title: str = tag_title.text.strip()
-    author: str = tag_author["href"].strip("/").split("/")[-1]
     date: str = parse_date(tag_date["title"].strip()).strftime("%Y-%m-%d")
     content: str = "".join(map(str, tag_content.children)).strip()
     mentions: List[str] = parse_mentions(tag_content)
-    user_icon_url: str = "https:" + tag_user_icon_url["src"]
 
     return {
+        **user_info,
         "id": id_,
-        "author": author,
         "title": title,
         "date": date,
         "content": content,
         "mentions": mentions,
-        "user_icon_url": user_icon_url,
     }
 
 
@@ -209,6 +211,66 @@ def parse_user_page(user_page: BeautifulSoup) -> Dict[str, str]:
     }
 
 
+def parse_user_folder(folder_page: BeautifulSoup) -> Dict[str, str]:
+    user: str = folder_page.select_one("div[class~=username] span").text.strip()
+    user_icon_url: str = "https:" + folder_page.select_one("img.user-nav-avatar")["src"]
+
+    return {
+        "user_name": user[1:],
+        "user_status": user[0],
+        "user_icon_url": user_icon_url,
+    }
+
+
+def parse_user_submissions(submissions_page: BeautifulSoup) -> Dict[str, Union[str, List[Tag], bool]]:
+    user_info: Dict[str, str] = parse_user_folder(submissions_page)
+    figures: List[Tag] = submissions_page.select("figure[id^='sid-']")
+
+    return {
+        **user_info,
+        "figures": figures,
+        "last_page": not figures,
+    }
+
+
+def parse_user_favorites(favorites_page: BeautifulSoup) -> Dict[str, Union[str, List[Tag], bool]]:
+    parsed_submissions = parse_user_journals(favorites_page)
+    tag_next_page: Optional[Tag] = favorites_page.select_one("a[class~=button][class~=standard][class~=right]")
+    next_page: str = tag_next_page["href"].split("/", 3)[-1] if tag_next_page else ""
+
+    return {
+        **parsed_submissions,
+        "next_page": next_page,
+    }
+
+
+def parse_user_journals(journals_page: BeautifulSoup) -> Dict[str, Union[str, List[Tag], bool]]:
+    user_info: Dict[str, str] = parse_user_folder(journals_page)
+    sections: List[Tag] = journals_page.select("section[id^='jid:']")
+
+    return {
+        **user_info,
+        "sections": sections,
+        "last_page": not sections,
+    }
+
+
+def parse_search_submissions(search_page: BeautifulSoup) -> Dict[str, Union[List[Tag], bool]]:
+    tag_stats: Tag = search_page.select_one("div[id='query-stats']")
+    for div in tag_stats.select("div"):
+        div.decompose()
+    a, b, tot = map(int, search(r"(\d+)[^\d]*(\d+)[^\d]*(\d+)", tag_stats.text.strip()).groups())
+    figures: List[Tag] = search_page.select("figure[id^='sid-']")
+
+    return {
+        "from": (a or 1) - 1,
+        "to": (b or 1) - 1,
+        "total": tot,
+        "figures": figures,
+        "last_page": b >= tot
+    }
+
+
 def parse_watchlist(watch_page: BeautifulSoup) -> List[Tuple[str, str]]:
     tags_users: List[Tag] = watch_page.select("div.watch-list-items")
     return [((u := t.text.strip().replace(" ", ""))[0], u[1:]) for t in tags_users]
