@@ -1,8 +1,11 @@
 from typing import Optional
 
+from .connection import join_url
+from .connection import root
 from .parse import BeautifulSoup
 from .parse import check_page_raise
 from .parse import parse_user_page
+from .parse import username_url
 
 
 class User:
@@ -30,9 +33,17 @@ class User:
     def __str__(self):
         return self.status + self.name
 
+    @property
+    def name_url(self):
+        return username_url(self.name.lower())
+
+    @property
+    def url(self):
+        return join_url(root, "user", self.name_url)
+
     def parse(self, user_page: BeautifulSoup = None):
         assert user_page is None or isinstance(user_page, BeautifulSoup)
-        self.user_page = user_page if user_page is not None else self.user_page
+        self.user_page = user_page or self.user_page
         if self.user_page is None:
             return
 
